@@ -22,22 +22,16 @@ namespace pika::concurrency::detail {
     {
         std::unique_lock<mutex_type> l(mtx_);
 
-        while (total_ > barrier_flag)
-        {
-            // Wait until everyone exits the barrier
-            cond_.wait(l);
-        }
+        // Wait until everyone exits the barrier
+        cond_.wait(l, [&] { return total_ <= barrier_flag; });
     }
 
     void barrier::wait()
     {
         std::unique_lock<mutex_type> l(mtx_);
 
-        while (total_ > barrier_flag)
-        {
-            // wait until everyone exits the barrier
-            cond_.wait(l);
-        }
+        // Wait until everyone exits the barrier
+        cond_.wait(l, [&] { return total_ <= barrier_flag; });
 
         // Are we the first to enter?
         if (total_ == barrier_flag) total_ = 0;
@@ -51,11 +45,9 @@ namespace pika::concurrency::detail {
         }
         else
         {
-            while (total_ < barrier_flag)
-            {
-                // wait until enough threads enter the barrier
-                cond_.wait(l);
-            }
+            // Wait until enough threads enter the barrier
+            cond_.wait(l, [&] { return total_ >= barrier_flag; });
+
             --total_;
 
             // get entering threads to wake up
