@@ -42,7 +42,7 @@ namespace pika::split_tuple_detail {
     template <typename Receiver>
     struct error_visitor
     {
-        PIKA_NO_UNIQUE_ADDRESS std::decay_t<Receiver> receiver;
+        std::decay_t<Receiver>& receiver;
 
         template <typename Error>
         void operator()(Error const& error)
@@ -187,7 +187,7 @@ namespace pika::split_tuple_detail {
         template <std::size_t Index, typename Receiver>
         struct stopped_error_value_visitor
         {
-            PIKA_NO_UNIQUE_ADDRESS std::decay_t<Receiver> receiver;
+            std::decay_t<Receiver>& receiver;
 
             [[noreturn]] void operator()(pika::detail::monostate) const { PIKA_UNREACHABLE; }
 
@@ -210,8 +210,7 @@ namespace pika::split_tuple_detail {
 
             void operator()(error_type const& error)
             {
-                pika::detail::visit(
-                    error_visitor<Receiver>{PIKA_FORWARD(Receiver, receiver)}, error);
+                pika::detail::visit(error_visitor<Receiver>{receiver}, error);
             }
 
             void operator()(value_type& t)
@@ -283,10 +282,7 @@ namespace pika::split_tuple_detail {
         }
 
         template <std::size_t Index, typename Receiver>
-        void add_continuation(Receiver& receiver) = delete;
-
-        template <std::size_t Index, typename Receiver>
-        void add_continuation(Receiver&& receiver)
+        void add_continuation(Receiver& receiver)
         {
             if (predecessor_done)
             {
@@ -294,9 +290,7 @@ namespace pika::split_tuple_detail {
                 // set_error/set_stopped/set_value has been called and
                 // values/errors have been stored into the shared state.
                 // We can trigger the continuation directly.
-                pika::detail::visit(
-                    stopped_error_value_visitor<Index, Receiver>{PIKA_FORWARD(Receiver, receiver)},
-                    v);
+                pika::detail::visit(stopped_error_value_visitor<Index, Receiver>{receiver}, v);
             }
             else
             {
@@ -312,9 +306,7 @@ namespace pika::split_tuple_detail {
                     // release the lock early and call the continuation
                     // directly again.
                     l.unlock();
-                    pika::detail::visit(stopped_error_value_visitor<Index, Receiver>{PIKA_FORWARD(
-                                            Receiver, receiver)},
-                        v);
+                    pika::detail::visit(stopped_error_value_visitor<Index, Receiver>{receiver}, v);
                 }
                 else
                 {
@@ -325,11 +317,9 @@ namespace pika::split_tuple_detail {
                     // to the vector and the vector is not threadsafe in
                     // itself. The continuation will be called later
                     // when set_error/set_stopped/set_value is called.
-                    continuations[Index] = [this,
-                                               receiver =
-                                                   PIKA_FORWARD(Receiver, receiver)]() mutable {
+                    continuations[Index] = [this, &receiver]() mutable {
                         pika::detail::visit(
-                            stopped_error_value_visitor<Index, Receiver>{PIKA_MOVE(receiver)}, v);
+                            stopped_error_value_visitor<Index, Receiver>{receiver}, v);
                     };
                 }
             }
@@ -463,7 +453,7 @@ namespace pika::split_tuple_detail {
                 pika::execution::experimental::start_t, operation_state& os) noexcept
             {
                 os.state->start();
-                os.state->template add_continuation<Index>(PIKA_MOVE(os.receiver));
+                os.state->template add_continuation<Index>(os.receiver);
             }
         };
 
@@ -533,15 +523,7 @@ namespace pika::split_tuple_detail {
 }    // namespace pika::split_tuple_detail
 
 namespace pika::execution::experimental {
-    /// \brief Splits a sender of a tuple into a tuple of senders.
-    ///
-    /// Sender adaptor that takes a sender that sends a single, non-empty, tuple
-    /// and returns a new tuple of the same size as the one sent by the input
-    /// sender which contains one sender for each element in the input sender
-    /// tuple. Each output sender signals completion whenever the input sender
-    /// would have signalled completion.
-    inline constexpr struct split_tuple_t final
-      : pika::functional::detail::tag_fallback<split_tuple_t>
+    struct split_tuple_t final : pika::functional::detail::tag_fallback<split_tuple_t>
     {
     private:
         template <typename Sender, PIKA_CONCEPT_REQUIRES_(is_sender_v<Sender>)>
@@ -567,5 +549,16 @@ namespace pika::execution::experimental {
         {
             return detail::partial_algorithm<split_tuple_t, Allocator>{allocator};
         }
-    } split_tuple{};
+    };
+
+    /// \brief Splits a sender of a tuple into a tuple of senders.
+    ///
+    /// Sender adaptor that takes a sender that sends a single, non-empty, tuple and returns a new
+    /// tuple of the same size as the one sent by the input sender which contains one sender for
+    /// each element in the input sender tuple. Each output sender signals completion whenever the
+    /// input sender would have signalled completion. The predecessor sender must complete with
+    /// exactly one tuple of at least one type.
+    ///
+    /// Added in 0.12.0.
+    inline constexpr split_tuple_t split_tuple{};
 }    // namespace pika::execution::experimental
