@@ -37,7 +37,7 @@ namespace pika::unpack_detail {
     template <typename Receiver>
     struct unpack_receiver_impl<Receiver>::unpack_receiver_type
     {
-        using is_receiver = void;
+        PIKA_STDEXEC_RECEIVER_CONCEPT
 
         PIKA_NO_UNIQUE_ADDRESS std::decay_t<Receiver> receiver;
 
@@ -148,7 +148,7 @@ namespace pika::unpack_detail {
     template <typename Sender>
     struct unpack_sender_impl<Sender>::unpack_sender_type
     {
-        using is_sender = void;
+        PIKA_STDEXEC_SENDER_CONCEPT
 
         PIKA_NO_UNIQUE_ADDRESS std::decay_t<Sender> sender;
 
