@@ -38,6 +38,16 @@ namespace pika::execution::detail {
         impl_->yield_k(k, desc);
     }
 
+    void agent_ref::spin_k(std::size_t k, const char* desc)
+    {
+        PIKA_ASSERT(*this == pika::execution::this_thread::detail::agent());
+        // verify that there are no more registered locks for this OS-thread
+#ifdef PIKA_HAVE_VERIFY_LOCKS
+        util::verify_no_locks();
+#endif
+        impl_->spin_k(k, desc);
+    }
+
     void agent_ref::suspend(const char* desc)
     {
         PIKA_ASSERT(*this == pika::execution::this_thread::detail::agent());
