@@ -12,13 +12,11 @@
 #include <pika/modules/program_options.hpp>
 #include <pika/modules/thread_manager.hpp>
 #include <pika/modules/topology.hpp>
-#include <pika/runtime/os_thread_type.hpp>
 #include <pika/runtime/runtime_fwd.hpp>
 #include <pika/runtime/shutdown_function.hpp>
 #include <pika/runtime/startup_function.hpp>
 #include <pika/runtime/state.hpp>
 #include <pika/runtime/thread_hooks.hpp>
-#include <pika/runtime/thread_mapper.hpp>
 #include <pika/runtime_configuration/runtime_configuration.hpp>
 #include <pika/threading_base/callback_notifier.hpp>
 
@@ -38,16 +36,15 @@
 #include <pika/config/warnings_prefix.hpp>
 
 ///////////////////////////////////////////////////////////////////////////////
-namespace pika {
-    namespace detail {
-        ///////////////////////////////////////////////////////////////////////
-        // There is no need to protect these global from thread concurrent
-        // access as they are access during early startup only.
-        extern std::list<startup_function_type> global_pre_startup_functions;
-        extern std::list<startup_function_type> global_startup_functions;
-        extern std::list<shutdown_function_type> global_pre_shutdown_functions;
-        extern std::list<shutdown_function_type> global_shutdown_functions;
-    }    // namespace detail
+namespace pika::detail {
+
+    ///////////////////////////////////////////////////////////////////////
+    // There is no need to protect these global from thread concurrent
+    // access as they are accessed during early startup only.
+    extern std::list<startup_function_type> global_pre_startup_functions;
+    extern std::list<startup_function_type> global_startup_functions;
+    extern std::list<shutdown_function_type> global_pre_shutdown_functions;
+    extern std::list<shutdown_function_type> global_shutdown_functions;
 
     ///////////////////////////////////////////////////////////////////////////
     class PIKA_EXPORT runtime
@@ -55,9 +52,8 @@ namespace pika {
     public:
         /// Generate a new notification policy instance for the given thread
         /// name prefix
-        using notification_policy_type = threads::callback_notifier;
-        virtual notification_policy_type get_notification_policy(
-            char const* prefix, os_thread_type type);
+        using notification_policy_type = pika::threads::callback_notifier;
+        virtual notification_policy_type get_notification_policy(char const* prefix);
 
         runtime_state get_state() const;
         void set_state(runtime_state s);
@@ -85,7 +81,7 @@ namespace pika {
         virtual ~runtime();
 
         /// \brief Manage list of functions to call on exit
-        void on_exit(util::detail::function<void()> const& f);
+        void on_exit(pika::util::detail::function<void()> const& f);
 
         /// \brief Manage runtime 'stopped' state
         void starting();
@@ -101,15 +97,10 @@ namespace pika {
 
         pika::util::runtime_configuration const& get_config() const;
 
-        std::size_t get_instance_number() const;
-
         /// \brief Return the system uptime measure on the thread executing this call
         static std::uint64_t get_system_uptime();
 
-        /// \brief Return a reference to the internal PAPI thread manager
-        util::thread_mapper& get_thread_mapper();
-
-        threads::detail::topology const& get_topology() const;
+        pika::threads::detail::topology const& get_topology() const;
 
         /// \brief Run the pika runtime system, use the given function for the
         ///        main \a thread and block waiting for all threads to
@@ -133,7 +124,7 @@ namespace pika {
         /// \returns          This function will return the value as returned
         ///                   as the result of the invocation of the function
         ///                   object given by the parameter \p func.
-        virtual int run(util::detail::function<pika_main_function_type> const& func);
+        virtual int run(pika::util::detail::function<pika_main_function_type> const& func);
 
         /// \brief Run the pika runtime system, initially use the given number
         ///        of (OS) threads in the thread-manager and block waiting for
@@ -163,8 +154,8 @@ namespace pika {
         ///                   return the value as returned as the result of the
         ///                   invocation of the function object given by the
         ///                   parameter \p func. Otherwise it will return zero.
-        virtual int start(
-            util::detail::function<pika_main_function_type> const& func, bool blocking = false);
+        virtual int start(pika::util::detail::function<pika_main_function_type> const& func,
+            bool blocking = false);
 
         /// \brief Start the runtime system
         ///
@@ -283,12 +274,6 @@ namespace pika {
         /// \param num              [in] The sequence number to use for thread
         ///                         registration. The default for this parameter
         ///                         is zero.
-        /// \param service_thread   [in] The thread should be registered as a
-        ///                         service thread. The default for this parameter
-        ///                         is 'true'. Any service threads will be pinned
-        ///                         to cores not currently used by any of the pika
-        ///                         worker threads.
-        ///
         /// \note The function will compose a thread name of the form
         ///       '<name>-thread#<num>' which is used to register the thread. It
         ///       is the user's responsibility to ensure that each (composed)
@@ -303,8 +288,8 @@ namespace pika {
         /// \returns This function will return whether the requested operation
         ///          succeeded or not.
         ///
-        virtual bool register_thread(char const* name, std::size_t num = 0,
-            bool service_thread = true, error_code& ec = throws);
+        virtual bool register_thread(
+            char const* name, std::size_t num = 0, error_code& ec = throws);
 
         /// \brief Unregister an external OS-thread with pika
         ///
@@ -320,14 +305,6 @@ namespace pika {
         ///
         virtual bool unregister_thread();
 
-        /// Access data for a given OS thread that was previously registered by
-        /// \a register_thread.
-        virtual os_thread_data get_os_thread_data(std::string const& label) const;
-
-        /// Enumerate all OS threads that have registered with the runtime.
-        virtual bool enumerate_os_threads(
-            util::detail::function<bool(os_thread_data const&)> const& f) const;
-
         notification_policy_type::on_startstop_type on_start_func() const;
         notification_policy_type::on_startstop_type on_stop_func() const;
         notification_policy_type::on_error_type on_error_func() const;
@@ -352,28 +329,21 @@ namespace pika {
         void init_global_data();
         void deinit_global_data();
 
-        threads::detail::thread_result_type run_helper(
-            util::detail::function<runtime::pika_main_function_type> const& func, int& result,
+        pika::threads::detail::thread_result_type run_helper(
+            pika::util::detail::function<runtime::pika_main_function_type> const& func, int& result,
             bool call_startup_functions);
 
         void wait_helper(std::mutex& mtx, std::condition_variable& cond, bool& running);
 
         // list of functions to call on exit
-        using on_exit_type = std::vector<util::detail::function<void()>>;
+        using on_exit_type = std::vector<pika::util::detail::function<void()>>;
         on_exit_type on_exit_functions_;
         mutable std::mutex mtx_;
 
         pika::util::runtime_configuration rtcfg_;
 
-        long instance_number_;
-        static std::atomic<int> instance_number_counter_;
-
-        // certain components (such as PAPI) require all threads to be
-        // registered with the library
-        std::unique_ptr<util::thread_mapper> thread_support_;
-
         // topology and affinity data
-        threads::detail::topology& topology_;
+        pika::threads::detail::topology& topology_;
 
         std::atomic<runtime_state> state_;
 
@@ -403,13 +373,11 @@ namespace pika {
 
         void deinit_tss_helper(char const* context, std::size_t num);
 
-        void init_tss_ex(char const* context, os_thread_type type, std::size_t local_thread_num,
-            std::size_t global_thread_num, char const* pool_name, char const* postfix,
-            bool service_thread, error_code& ec);
+        void init_tss_ex(char const* context, std::size_t local_thread_num,
+            std::size_t global_thread_num, char const* pool_name, char const* postfix);
 
-        void init_tss_helper(char const* context, os_thread_type type, std::size_t local_thread_num,
-            std::size_t global_thread_num, char const* pool_name, char const* postfix,
-            bool service_thread);
+        void init_tss_helper(char const* context, std::size_t local_thread_num,
+            std::size_t global_thread_num, char const* pool_name, char const* postfix);
 
         void notify_finalize();
         void wait_finalize();
@@ -429,9 +397,7 @@ namespace pika {
 
     PIKA_EXPORT void set_signal_handlers();
 
-    namespace detail {
-        PIKA_EXPORT char const* get_runtime_state_name(pika::runtime_state st);
-    }
+    PIKA_EXPORT char const* get_runtime_state_name(pika::runtime_state st);
 
     namespace util {
         ///////////////////////////////////////////////////////////////////////////
@@ -468,6 +434,9 @@ namespace pika {
         PIKA_EXPORT std::ptrdiff_t get_stack_size(execution::thread_stacksize);
     }    // namespace threads
 
+}    // namespace pika::detail
+
+namespace pika {
     /// Returns true when the runtime is initialized, false otherwise.
     ///
     /// Returns true while in a @ref pika::init call, or between calls of @ref pika::start and @ref
