@@ -202,7 +202,7 @@ namespace pika::threads::detail {
     template <typename Lock>
     void scheduled_thread_pool<Scheduler>::stop_locked(Lock& l, bool blocking)
     {
-        LTM_(info).format("stop: {} blocking({})", id_.name(), blocking);
+        PIKA_LOG(info, "stop: {} blocking({})", id_.name(), blocking);
 
         if (!threads_.empty())
         {
@@ -227,11 +227,11 @@ namespace pika::threads::detail {
                     if (!threads_[i].joinable()) continue;
 
                     // make sure no OS thread is waiting
-                    LTM_(info).format("stop: {} notify_all", id_.name());
+                    PIKA_LOG(info, "stop: {} notify_all", id_.name());
 
                     sched_->Scheduler::do_some_work(std::size_t(-1));
 
-                    LTM_(info).format("stop: {} join:{}", id_.name(), i);
+                    PIKA_LOG(info, "stop: {} join:{}", id_.name(), i);
 
                     {
                         // unlock the lock while joining
@@ -257,9 +257,9 @@ namespace pika::threads::detail {
     {
         PIKA_ASSERT(l.owns_lock());
 
-        LTM_(info).format("run: {} number of processing units available: {}", id_.name(),
+        PIKA_LOG(info, "run: {} number of processing units available: {}", id_.name(),
             threads::detail::hardware_concurrency());
-        LTM_(info).format("run: {} creating {} OS thread(s)", id_.name(), pool_threads);
+        PIKA_LOG(info, "run: {} creating {} OS thread(s)", id_.name(), pool_threads);
 
         if (0 == pool_threads)
         {
@@ -274,7 +274,7 @@ namespace pika::threads::detail {
         init_perf_counter_data(pool_threads);
         this->init_pool_time_scale();
 
-        LTM_(info).format("run: {} timestamp_scale: {}", id_.name(), timestamp_scale_);
+        PIKA_LOG(info, "run: {} timestamp_scale: {}", id_.name(), timestamp_scale_);
 
         // run threads and wait for initialization to complete
         std::size_t thread_num = 0;
@@ -296,8 +296,9 @@ namespace pika::threads::detail {
                 // get_pu_mask expects index according to ordering of masks
                 // in affinity_data::affinity_masks_
                 // which is in order of occupied PU
-                LTM_(info).format("run: {} create OS thread {}: will run on processing units "
-                                  "within this mask: {}",
+                PIKA_LOG(info,
+                    "run: {} create OS thread {}: will run on processing units "
+                    "within this mask: {}",
                     id_.name(), global_thread_num, pika::threads::detail::to_string(mask));
 
                 // create a new thread
@@ -311,7 +312,7 @@ namespace pika::threads::detail {
         }
         catch (std::exception const& e)
         {
-            LTM_(always).format("run: {} failed with: {}", id_.name(), e.what());
+            PIKA_LOG(critical, "run: {} failed with: {}", id_.name(), e.what());
 
             // trigger the barrier
             pool_threads -= (thread_num + 1);
@@ -323,7 +324,7 @@ namespace pika::threads::detail {
             return false;
         }
 
-        LTM_(info).format("run: {} running", id_.name());
+        PIKA_LOG(info, "run: {} running", id_.name());
         return true;
     }
 
@@ -400,13 +401,13 @@ namespace pika::threads::detail {
         // process may have a non-full mask set which is inherited by this thread.
         if (!any(mask)) { mask = topo.get_machine_affinity_mask(); }
 
-        if (LPIKA_ENABLED(debug)) topo.write_to_log();
+        if (PIKA_LOG_ENABLED(debug)) topo.write_to_log();
 
         error_code ec(throwmode::lightweight);
         topo.set_thread_affinity_mask(mask, ec);
         if (ec)
         {
-            LTM_(warning).format(
+            PIKA_LOG(warn,
                 "thread_func: {} setting thread affinity on OS thread {} failed with: {}",
                 id_.name(), global_thread_num, ec.get_message());
         }
@@ -420,7 +421,7 @@ namespace pika::threads::detail {
             topo.reduce_thread_priority(ec);
             if (ec)
             {
-                LTM_(warning).format(
+                PIKA_LOG(warn,
                     "thread_func: {} reducing thread priority on OS thread {} failed with: {}",
                     id_.name(), global_thread_num, ec.get_message());
             }
@@ -439,7 +440,7 @@ namespace pika::threads::detail {
         // wait for all threads to start up before before starting pika work
         startup->wait();
 
-        LTM_(info).format("thread_func: {} starting OS thread: {}", id_.name(), thread_num);
+        PIKA_LOG(info, "thread_func: {} starting OS thread: {}", id_.name(), thread_num);
 
         try
         {
@@ -474,8 +475,9 @@ namespace pika::threads::detail {
             }
             catch (pika::exception const& e)
             {
-                LFATAL_.format("thread_func: {} thread_num:{} : caught pika::exception: {}, "
-                               "aborted thread execution",
+                PIKA_LOG(critical,
+                    "thread_func: {} thread_num:{} : caught pika::exception: {}, "
+                    "aborted thread execution",
                     id_.name(), global_thread_num, e.what());
 
                 report_error(global_thread_num, std::current_exception());
@@ -483,8 +485,9 @@ namespace pika::threads::detail {
             }
             catch (std::system_error const& e)
             {
-                LFATAL_.format("thread_func: {} thread_num:{} : caught std::system_error: {}, "
-                               "aborted thread execution",
+                PIKA_LOG(critical,
+                    "thread_func: {} thread_num:{} : caught std::system_error: {}, "
+                    "aborted thread execution",
                     id_.name(), global_thread_num, e.what());
 
                 report_error(global_thread_num, std::current_exception());
@@ -498,16 +501,16 @@ namespace pika::threads::detail {
         }
         catch (...)
         {
-            LFATAL_.format("thread_func: {} thread_num:{} : caught unexpected exception, aborted "
-                           "thread execution",
+            PIKA_LOG(critical,
+                "thread_func: {} thread_num:{} : caught unexpected exception, aborted "
+                "thread execution",
                 id_.name(), global_thread_num);
 
             report_error(global_thread_num, std::current_exception());
             return;
         }
 
-        LTM_(info).format(
-            "thread_func: {} thread_num: {}, ending OS thread, executed {} pika threads",
+        PIKA_LOG(info, "thread_func: {} thread_num: {}, ending OS thread, executed {} pika threads",
             id_.name(), global_thread_num,
             counter_data_[global_thread_num].data_.executed_threads_);
     }
