@@ -9,11 +9,10 @@
 #include <pika/config.hpp>
 
 #if defined(WIN32) || defined(_WIN32) || defined(__WIN32__)
-#include <windows.h>
+# include <windows.h>
 
 namespace pika::detail {
-    PIKA_EXPORT void set_thread_name(
-        char const* /*threadName*/, DWORD /*dwThreadID*/ = DWORD(-1));
+    PIKA_EXPORT void set_thread_name(char const* /*threadName*/, DWORD /*dwThreadID*/ = DWORD(-1));
 }    // namespace pika::detail
 
 #else
