@@ -9,7 +9,6 @@
 #include <pika/coroutines/thread_enums.hpp>
 #include <pika/errors/throw_exception.hpp>
 #include <pika/lock_registration/detail/register_locks.hpp>
-#include <pika/modules/logging.hpp>
 #include <pika/threading_base/thread_data.hpp>
 #include <pika/threading_base/thread_num_tss.hpp>
 
@@ -185,6 +184,6 @@ namespace pika::threads::detail {
             execution::thread_priority::normal,
             execution::thread_schedule_hint{
                 static_cast<std::int16_t>(get_thread_id_data(thrd)->get_last_worker_thread_num())},
-            false);
+            true);
     }
 }    // namespace pika::threads::detail
